@@ -110,6 +110,10 @@ use itertools::Itertools;
 use std::ops::Range;
 use xor_name::XorName;
 
+// export these because they are used in our public API.
+pub use bytes;
+pub use xor_name;
+
 /// The minimum size (before compression) of data to be self-encrypted, defined as 3kB.
 pub const MIN_ENCRYPTABLE_BYTES: usize = 3 * MIN_CHUNK_SIZE;
 /// The maximum size (before compression) of an individual chunk of the file, defined as 1MB.
@@ -344,15 +348,13 @@ fn get_start_position(file_size: usize, chunk_index: usize) -> usize {
     if total_chunks == 0 {
         return 0;
     }
-    let start;
     let last = (total_chunks - 1) == chunk_index;
     let first_chunk_size = get_chunk_size(file_size, 0);
     if last {
-        start = first_chunk_size * (chunk_index - 1) + get_chunk_size(file_size, chunk_index - 1);
+        first_chunk_size * (chunk_index - 1) + get_chunk_size(file_size, chunk_index - 1)
     } else {
-        start = first_chunk_size * chunk_index;
+        first_chunk_size * chunk_index
     }
-    start
 }
 
 fn get_chunk_index(file_size: usize, position: usize) -> usize {
